@@ -1,8 +1,10 @@
 
 from skimage.transform import resize
 import numpy as np
+import pathlib
+import os
 
-weight = "model_optimized.tflite"
+weight = os.path.join(pathlib.Path(__file__).parent.absolute(), "model_optimized.tflite")
 
 import numpy as np
 import tensorflow as tf
